@@ -1,9 +1,26 @@
 package Catalyst::Helper::View::GD::Barcode::QRcode;
 
 use strict;
-use warnings;
 
-our $VERSION = '0.01';
+=head1 NAME
+
+Catalyst::Helper::View::GD::Barcode::QRcode - Helper for GD::Barcode::QRcode Views
+
+
+=head1 SYNOPSIS
+
+    script/create.pl view MyQRcode GD::Barcode::QRcode
+
+
+=head1 DESCRIPTION
+
+Helper for GD::Barcode::QRcode Views.
+
+=head2 METHODS
+
+=head3 mk_compclass
+
+=cut
 
 sub mk_compclass {
     my ( $self, $helper ) = @_;
@@ -11,6 +28,29 @@ sub mk_compclass {
     $helper->render_file( 'compclass', $file );
 }
 
+=head1 SEE ALSO
+
+F<Catalyst>, F<Catalyst::View::GD::Barcode::QRcode>, F<GD::Barcode::QRcode>.
+
+
+=head1 AUTHOR
+
+Hideo Kimura C<< <<hide@hide-k.net>> >>
+
+
+=head1 LICENSE
+
+This program is free software; you can redistribute
+it and/or modify it under the same terms as Perl itself.
+
+The full text of the license can be found in the
+LICENSE file included with this module.
+
+
+=cut
+
+1;
+
 __DATA__
 
 __compclass__
@@ -43,41 +83,3 @@ it under the same terms as Perl itself.
 =cut
 
 1;
-__END__
-
-=head1 NAME
-
-Catalyst::Helper::View::GD::Barcode::QRcode - Helper for GD::Barcode::QRcode Views
-
-
-=head1 SYNOPSIS
-
-    script/create.pl view MyQRcode GD::Barcode::QRcode
-
-
-=head1 DESCRIPTION
-
-Helper for GD::Barcode::QRcode Views.
-
-
-=head1 AUTHOR
-
-Hideo Kimura C<< <<hide@hide-k.net>> >>
-
-
-=head1 LICENSE
-
-This program is free software; you can redistribute
-it and/or modify it under the same terms as Perl itself.
-
-The full text of the license can be found in the
-LICENSE file included with this module.
-
-
-
-=head1 SEE ALSO
-
-F<Catalyst>, F<Catalyst::View::GD::Barcode::QRcode>, F<GD::Barcode::QRcode>.
-
-
-=cut
